﻿using Blazorise.DataGrid;
using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Localization;
using System;
using System.Security.Claims;
using System.Text.Json;
using WF_WebAdmin.Model;


namespace WF_WebAdmin.Pages
{
    public partial class Accueil
    {
        private Quote[]? Dailyquote;
        [Inject]
        public ILogger<Accueil>? Logger { get; set; }

        [Inject]
        public HttpClient? Http { get; set; }

        [Inject]
        public NavigationManager? NavigationManager { get; set; }

        [Inject]
        public IStringLocalizer<Accueil>? Localizer { get; set; }


        /// <summary>
        /// This method is called during the initialization of the Blazor component.
        /// It is asynchronous and is used to load data or perform actions before the component is rendered.
        /// </summary>
        protected override async Task OnInitializedAsync()
        {
            var url = $"{NavigationManager.BaseUri}fake-dataDailyQuote.json";
    
            try
            {
                var response = await Http.GetFromJsonAsync<Quote[]>(url);
                Dailyquote = response ?? Array.Empty<Quote>(); // Assurer qu'on ne stocke pas null
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Erreur lors du chargement des citations : {ex.Message}");
                Dailyquote = Array.Empty<Quote>(); // Éviter une exception en cas d'erreur réseau
            }
        }
        private async Task RandomDailyquote()
        {
            try
            {
                string _jsonFilePath = Path.Combine(Environment.CurrentDirectory, "wwwroot", "fake-dataDailyQuote.json");
                Random random = new Random();

                var response = await Http.GetFromJsonAsync<Quote[]>($"{NavigationManager.BaseUri}fake-dataQuote.json");
                Quote[] quotes = response ?? Array.Empty<Quote>(); // Empêche null

                if (quotes.Length > 0)
                {
                    Dailyquote = new Quote[] { quotes.OrderBy(x => random.Next()).First() };
                }
                else
                {
                    Console.WriteLine("Aucune citation disponible dans le fichier JSON.");
                    return;
                }

                var json = JsonSerializer.Serialize(Dailyquote, new JsonSerializerOptions { WriteIndented = true });
                await File.WriteAllTextAsync(_jsonFilePath, json);

                if (Logger != null)
                {
                    LoggerSaveStub.Log(Logger, LogLevel.Information, "Random change of quote of the day");
                }
                else
                {
                    Console.WriteLine("Logger non initialisé.");
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Erreur dans RandomDailyquote: {ex.Message}");
            }
        }
    }
}

